@@ -1,4 +1,5 @@
 
+from django.apps import apps
 from django.conf import settings
 from django.contrib import messages
 from django.template.loader import render_to_string
@@ -12,7 +13,8 @@ def get_new_order_context(order):
     return {
         'order': order,
         'title': '{} #{}'.format(_('New order'), order.id),
-        'site': Site.objects.get_current()
+        'site': Site.objects.get_current(),
+        'is_clothes_app_enabled': apps.is_installed('clothes')
     }
 
 
@@ -50,4 +52,6 @@ def send_new_order_notifications(request, order):
 
     send_new_order_email(context)
     send_new_order_sms(context)
-    push_new_order_message_to_session(request, context)
+
+    if not order.is_liqpay_payment():
+        push_new_order_message_to_session(request, context)
